
% POST PROCESSING ROUTINE FOR SPHYSICS_SWE_1D. THIS PROGRAM GENERATES PARTICLE
% PLOTS OF THE RESULTS USING THE PART_ijkl AND DT FILES AS INPUT.
% THIS PROGRAM SEARCHES FOR THE PART_ijkk and DT FILES IN THE 
% CURRENT MATLAB WORKING DIRECTORY. 

clear all
close all
clc

%READ PARAMETERS FROM MATLABIN
load matlabin;
np=matlabin(1);
vlx=matlabin(2);
out=matlabin(3);

%IF THE SIMULATION IS COMPLETE LOAD THE TIME INFORMATION FROM FILE DT. IF
%SIMULATION IS ONGOING, JUST PLOT USER SPECIFIED FRAMES
irun=input('Is the run complete? (1=Yes,0=No)  ');
if(irun==1)
    %LOAD AND READ TIME,DT FROM FILE DT. THE FIRST HEADLINE IN THE FILE IS
    %SKIPPED
    [time,DT1,DT2,DT]=textread('dt','%f %f %f %f','headerlines',1);
    %THE NUMBER OF PARTFILES, Nframes, IS ONE LESS THAN THE LENGTH OF THE time VECTOR.
    %THIS IS BECAUSE THE LAST VALUE OF THE TIME VECTOR IS ASSOCIATED WITH EPART
    Nframes=length(time);
else
    fprintf('Number of PART files to be visualized \n');
    Nframes=input('(enter 0 for initial conditions) = ');
end
sframes=input('Do you want to save frames? (1=Yes,0=No)  ');

%INITIALIZE FIGURE AND SET PROPERTIES
XF=figure;
set(XF,'DefaultAxesFontSize',14)
set(XF,'DefaultTextFontSize',14)

%SET NORMALIZED FIGURE POSITION AND SIZE TO MAKE IT CONSISTENT OVER ALL
%MONITORS
set(XF,'Units','normalized')
set(gcf,'Position',[0.1,0.5,0.8,0.4])


%INITIALIZE PARTICLE SIZE, VARIABLE M FOR MOVIES, PLOT AXES AND
%POSITION OF TEXT
ParticleSize=3;
M=moviein(Nframes);
xmin=-0.01;
xmax=1.05*vlx;
zmin=0;
zmax=1.1;

ll=0;
for ii=1:Nframes
    %READ IN EACH FRAME INTO PART1,PART2...PART'EFRAME'
    if ((ii>0)& (ii< 10)) 
        eval(['fn =','''PART_000', int2str(ii),'''',';'])
        PART=load(fn);
    elseif ((ii>=10) & (ii<100)) 
        eval(['fn =','''PART_00', int2str(ii),'''',';'])
        PART=load(fn);
    elseif ((ii>=100) & (ii<1000)) 
        eval(['fn =','''PART_0', int2str(ii),'''',';'])
        PART=load(fn);
    elseif ((ii>=1000) & (ii<10000)) 
        eval(['fn =','''PART_', int2str(ii),'''',';'])
        PART=load(fn);
    end
    
    %filter points outside domain
    kk=0;
    TEMP_PART=zeros(length(PART(:,1)),length(PART(1,:)));
    for i=1:length(PART(:,1))
        if ( PART(i,1)<vlx && PART(i,1)>0 )
           kk=kk+1;
           TEMP_PART(kk,:)=PART(i,:);
        end
    end
    PART=TEMP_PART(1:kk,:);  
    np=length(PART(:,1));
          
%   PLOT FIXED BOUNDARY PARTICLES AND WATER PARTICLES
    figure(XF)
    subplot(1,2,1) %velocity
    plot(PART(1:np,1),PART(1:np,2),'ko-','MarkerSize',ParticleSize,'LineWidth',0.1)
%   SET AXES, LABELS AND TITLE
%    axis([xmin xmax zmin zmax])
    xlabel('X(m)')
    ylabel('v (m/s)')
    hold on
   if(irun==1)
       title(['VELOCITY, Time=',num2str(time(ii)),'s : ','  FRAME=',num2str(ii)])
   else
       title(['  FRAME=',num2str(ii)])
   end
   grid on
   hold off
    
    subplot(1,2,2) %water level
    plot(PART(1:np,1),PART(1:np,3)+PART(1:np,4),'ko-', 'MarkerSize',ParticleSize,'LineWidth',0.1)% , axis([0 1 0 0.5])
    hold on
    plot(PART(1:np,1),PART(1:np,4),'k' )
%    plot( PART(1:np,1),eta,'r--','LineWidth',3) %analitical solutions of parabolic
    hold off
%   SET AXES, LABELS AND TITLE
%    axis([xmin xmax zmin zmax])
    xlabel('X(m)')
    ylabel('h (m)')
    grid on
    
%    figure(3)
%    subplot(1,2,1) %h
%    plot(PART(1:np,1),PART(1:np,4), 'MarkerSize',ParticleSize) % , axis([0 2 0 1.1])
%   SET AXES, LABELS AND TITLE
%    axis([xmin xmax zmin zmax])
%    xlabel('X(m)')
%    ylabel('smoothing length')
%    grid on
    
    %Plot Dx - x to see if the particle switch each others
%    deltax=zeros(np,1);
%    lim_kern=zeros(np,1);
    
%    lim_kern(:)=0.6*smo_len; % maximum of dW/dr for cubic kernel
    
%    for i=2:np
%        deltax(i)=PART(i,1)-PART(i-1,1);
%    end
    
%    dhdx=zeros(np,1);
%    coeff=polyfit(PART(1:np,1),PART(1:np,3),1);
%    dhdx(:)=coeff(1);
    
%    subplot(1,2,2)
%    plot( PART(1:np,1),PART(1:np,10),'o') ,xlabel('X(m)'), ylabel('acceleration (m/s^2'), grid on
%     hold on
%     plot( PART(1:np,1),lim_kern,'r');
%     hold off
%     xlabel('X(m)')
%     ylabel('DX(m)')
%     grid on
    
%    h=get(gcf,'CurrentAxes');
%    ll=ll+1;
%   GET FRAME FOR STORING A MOVIE    
%    M1(:,ll)=getframe(gcf);
    
%    figure(2)
%    subplot(1,2,1)
%    plot(PART(1:np,1),PART(1:np,7) ), xlabel('X(m)'), ylabel('alpha'), grid on
%    if irun==1
%      title(['alpha, Time=',num2str(time(ii)),'s : ','  FRAME=',num2str(ii)])
%    else
%      title(['alpha FRAME=',num2str(ii)])
%    end
        
%    subplot(1,2,2)
%    plot(PART(1:np,1),PART(1:np,8) ), xlabel('X(m)'), ylabel('Res_adm'), grid on
    
    %clear PART
    if(sframes==1)
    eval(['print -djpeg -r300 ', '''frame',num2str(ii),'.jpg''',';'])
    end
    pause

end

